? GNUmakefile
? config.log
? config.status
? src/Makefile.global
? src/Makefile.port
? src/backend/postgres.def
? src/backend/catalog/postgres.bki
? src/backend/catalog/postgres.description
? src/backend/po/af.mo
? src/backend/po/cs.mo
? src/backend/po/de.mo
? src/backend/po/es.mo
? src/backend/po/fr.mo
? src/backend/po/hr.mo
? src/backend/po/hu.mo
? src/backend/po/it.mo
? src/backend/po/ko.mo
? src/backend/po/nb.mo
? src/backend/po/pt_BR.mo
? src/backend/po/ro.mo
? src/backend/po/ru.mo
? src/backend/po/sk.mo
? src/backend/po/sl.mo
? src/backend/po/sv.mo
? src/backend/po/tr.mo
? src/backend/po/zh_CN.mo
? src/backend/po/zh_TW.mo
? src/backend/port/dynloader.c
? src/backend/port/pg_sema.c
? src/backend/port/pg_shmem.c
? src/backend/port/tas.s
? src/backend/utils/mb/conversion_procs/conversion_create.sql
? src/backend/utils/mb/conversion_procs/ascii_and_mic/ascii_and_mic.def
? src/backend/utils/mb/conversion_procs/cyrillic_and_mic/cyrillic_and_mic.def
? src/backend/utils/mb/conversion_procs/euc_cn_and_mic/euc_cn_and_mic.def
? src/backend/utils/mb/conversion_procs/euc_jp_and_sjis/euc_jp_and_sjis.def
? src/backend/utils/mb/conversion_procs/euc_kr_and_mic/euc_kr_and_mic.def
? src/backend/utils/mb/conversion_procs/euc_tw_and_big5/euc_tw_and_big5.def
? src/backend/utils/mb/conversion_procs/latin2_and_win1250/latin2_and_win1250.def
? src/backend/utils/mb/conversion_procs/latin_and_mic/latin_and_mic.def
? src/backend/utils/mb/conversion_procs/utf8_and_ascii/utf8_and_ascii.def
? src/backend/utils/mb/conversion_procs/utf8_and_big5/utf8_and_big5.def
? src/backend/utils/mb/conversion_procs/utf8_and_cyrillic/utf8_and_cyrillic.def
? src/backend/utils/mb/conversion_procs/utf8_and_euc_cn/utf8_and_euc_cn.def
? src/backend/utils/mb/conversion_procs/utf8_and_euc_jp/utf8_and_euc_jp.def
? src/backend/utils/mb/conversion_procs/utf8_and_euc_kr/utf8_and_euc_kr.def
? src/backend/utils/mb/conversion_procs/utf8_and_euc_tw/utf8_and_euc_tw.def
? src/backend/utils/mb/conversion_procs/utf8_and_gb18030/utf8_and_gb18030.def
? src/backend/utils/mb/conversion_procs/utf8_and_gbk/utf8_and_gbk.def
? src/backend/utils/mb/conversion_procs/utf8_and_iso8859/utf8_and_iso8859.def
? src/backend/utils/mb/conversion_procs/utf8_and_iso8859_1/utf8_and_iso8859_1.def
? src/backend/utils/mb/conversion_procs/utf8_and_johab/utf8_and_johab.def
? src/backend/utils/mb/conversion_procs/utf8_and_sjis/utf8_and_sjis.def
? src/backend/utils/mb/conversion_procs/utf8_and_uhc/utf8_and_uhc.def
? src/backend/utils/mb/conversion_procs/utf8_and_win1250/utf8_and_win1250.def
? src/backend/utils/mb/conversion_procs/utf8_and_win1252/utf8_and_win1252.def
? src/backend/utils/mb/conversion_procs/utf8_and_win1256/utf8_and_win1256.def
? src/backend/utils/mb/conversion_procs/utf8_and_win1258/utf8_and_win1258.def
? src/backend/utils/mb/conversion_procs/utf8_and_win874/utf8_and_win874.def
? src/bin/initdb/po/cs.mo
? src/bin/initdb/po/de.mo
? src/bin/initdb/po/es.mo
? src/bin/initdb/po/fr.mo
? src/bin/initdb/po/it.mo
? src/bin/initdb/po/ko.mo
? src/bin/initdb/po/pl.mo
? src/bin/initdb/po/pt_BR.mo
? src/bin/initdb/po/ro.mo
? src/bin/initdb/po/ru.mo
? src/bin/initdb/po/sk.mo
? src/bin/initdb/po/sl.mo
? src/bin/initdb/po/sv.mo
? src/bin/initdb/po/tr.mo
? src/bin/initdb/po/zh_CN.mo
? src/bin/initdb/po/zh_TW.mo
? src/bin/ipcclean/ipcclean
? src/bin/pg_config/po/cs.mo
? src/bin/pg_config/po/de.mo
? src/bin/pg_config/po/es.mo
? src/bin/pg_config/po/fr.mo
? src/bin/pg_config/po/ko.mo
? src/bin/pg_config/po/pl.mo
? src/bin/pg_config/po/pt_BR.mo
? src/bin/pg_config/po/ro.mo
? src/bin/pg_config/po/ru.mo
? src/bin/pg_config/po/sl.mo
? src/bin/pg_config/po/sv.mo
? src/bin/pg_config/po/tr.mo
? src/bin/pg_config/po/zh_CN.mo
? src/bin/pg_config/po/zh_TW.mo
? src/bin/pg_controldata/pg_crc.c
? src/bin/pg_controldata/po/cs.mo
? src/bin/pg_controldata/po/de.mo
? src/bin/pg_controldata/po/es.mo
? src/bin/pg_controldata/po/fa.mo
? src/bin/pg_controldata/po/fr.mo
? src/bin/pg_controldata/po/hu.mo
? src/bin/pg_controldata/po/it.mo
? src/bin/pg_controldata/po/ko.mo
? src/bin/pg_controldata/po/nb.mo
? src/bin/pg_controldata/po/pl.mo
? src/bin/pg_controldata/po/pt_BR.mo
? src/bin/pg_controldata/po/ro.mo
? src/bin/pg_controldata/po/ru.mo
? src/bin/pg_controldata/po/sk.mo
? src/bin/pg_controldata/po/sl.mo
? src/bin/pg_controldata/po/sv.mo
? src/bin/pg_controldata/po/tr.mo
? src/bin/pg_controldata/po/zh_CN.mo
? src/bin/pg_controldata/po/zh_TW.mo
? src/bin/pg_ctl/po/cs.mo
? src/bin/pg_ctl/po/de.mo
? src/bin/pg_ctl/po/es.mo
? src/bin/pg_ctl/po/fr.mo
? src/bin/pg_ctl/po/ko.mo
? src/bin/pg_ctl/po/pt_BR.mo
? src/bin/pg_ctl/po/ro.mo
? src/bin/pg_ctl/po/ru.mo
? src/bin/pg_ctl/po/sk.mo
? src/bin/pg_ctl/po/sl.mo
? src/bin/pg_ctl/po/sv.mo
? src/bin/pg_ctl/po/tr.mo
? src/bin/pg_ctl/po/zh_CN.mo
? src/bin/pg_ctl/po/zh_TW.mo
? src/bin/pg_dump/po/cs.mo
? src/bin/pg_dump/po/de.mo
? src/bin/pg_dump/po/es.mo
? src/bin/pg_dump/po/fr.mo
? src/bin/pg_dump/po/it.mo
? src/bin/pg_dump/po/ko.mo
? src/bin/pg_dump/po/nb.mo
? src/bin/pg_dump/po/pt_BR.mo
? src/bin/pg_dump/po/ro.mo
? src/bin/pg_dump/po/ru.mo
? src/bin/pg_dump/po/sk.mo
? src/bin/pg_dump/po/sl.mo
? src/bin/pg_dump/po/sv.mo
? src/bin/pg_dump/po/tr.mo
? src/bin/pg_dump/po/zh_CN.mo
? src/bin/pg_dump/po/zh_TW.mo
? src/bin/pg_resetxlog/pg_crc.c
? src/bin/pg_resetxlog/po/cs.mo
? src/bin/pg_resetxlog/po/de.mo
? src/bin/pg_resetxlog/po/es.mo
? src/bin/pg_resetxlog/po/fr.mo
? src/bin/pg_resetxlog/po/hu.mo
? src/bin/pg_resetxlog/po/it.mo
? src/bin/pg_resetxlog/po/ko.mo
? src/bin/pg_resetxlog/po/nb.mo
? src/bin/pg_resetxlog/po/pt_BR.mo
? src/bin/pg_resetxlog/po/ro.mo
? src/bin/pg_resetxlog/po/ru.mo
? src/bin/pg_resetxlog/po/sk.mo
? src/bin/pg_resetxlog/po/sl.mo
? src/bin/pg_resetxlog/po/sv.mo
? src/bin/pg_resetxlog/po/tr.mo
? src/bin/pg_resetxlog/po/zh_CN.mo
? src/bin/pg_resetxlog/po/zh_TW.mo
? src/bin/pgevent/win32ver.rc
? src/bin/psql/po/cs.mo
? src/bin/psql/po/de.mo
? src/bin/psql/po/es.mo
? src/bin/psql/po/fa.mo
? src/bin/psql/po/fr.mo
? src/bin/psql/po/hu.mo
? src/bin/psql/po/it.mo
? src/bin/psql/po/ko.mo
? src/bin/psql/po/nb.mo
? src/bin/psql/po/pt_BR.mo
? src/bin/psql/po/ro.mo
? src/bin/psql/po/ru.mo
? src/bin/psql/po/sk.mo
? src/bin/psql/po/sl.mo
? src/bin/psql/po/sv.mo
? src/bin/psql/po/tr.mo
? src/bin/psql/po/zh_CN.mo
? src/bin/psql/po/zh_TW.mo
? src/bin/scripts/dumputils.c
? src/bin/scripts/mbprint.c
? src/bin/scripts/print.c
? src/bin/scripts/po/cs.mo
? src/bin/scripts/po/de.mo
? src/bin/scripts/po/es.mo
? src/bin/scripts/po/fr.mo
? src/bin/scripts/po/it.mo
? src/bin/scripts/po/ko.mo
? src/bin/scripts/po/pt_BR.mo
? src/bin/scripts/po/ro.mo
? src/bin/scripts/po/ru.mo
? src/bin/scripts/po/sk.mo
? src/bin/scripts/po/sl.mo
? src/bin/scripts/po/sv.mo
? src/bin/scripts/po/tr.mo
? src/bin/scripts/po/zh_CN.mo
? src/bin/scripts/po/zh_TW.mo
? src/include/dynloader.h
? src/include/pg_config.h
? src/include/pg_config_os.h
? src/include/stamp-h
? src/include/parser/parse.h
? src/include/utils/fmgroids.h
? src/interfaces/ecpg/compatlib/ecpg_compat.def
? src/interfaces/ecpg/ecpglib/ecpg.def
? src/interfaces/ecpg/ecpglib/exec.c
? src/interfaces/ecpg/ecpglib/path.c
? src/interfaces/ecpg/pgtypeslib/pgstrcasecmp.c
? src/interfaces/ecpg/pgtypeslib/pgtypes.def
? src/interfaces/libpq/crypt.c
? src/interfaces/libpq/encnames.c
? src/interfaces/libpq/getaddrinfo.c
? src/interfaces/libpq/inet_aton.c
? src/interfaces/libpq/ip.c
? src/interfaces/libpq/md5.c
? src/interfaces/libpq/noblock.c
? src/interfaces/libpq/open.c
? src/interfaces/libpq/pgstrcasecmp.c
? src/interfaces/libpq/thread.c
? src/interfaces/libpq/wchar.c
? src/interfaces/libpq/po/af.mo
? src/interfaces/libpq/po/cs.mo
? src/interfaces/libpq/po/de.mo
? src/interfaces/libpq/po/es.mo
? src/interfaces/libpq/po/fr.mo
? src/interfaces/libpq/po/hr.mo
? src/interfaces/libpq/po/it.mo
? src/interfaces/libpq/po/ko.mo
? src/interfaces/libpq/po/nb.mo
? src/interfaces/libpq/po/pl.mo
? src/interfaces/libpq/po/pt_BR.mo
? src/interfaces/libpq/po/ru.mo
? src/interfaces/libpq/po/sk.mo
? src/interfaces/libpq/po/sl.mo
? src/interfaces/libpq/po/sv.mo
? src/interfaces/libpq/po/tr.mo
? src/interfaces/libpq/po/zh_CN.mo
? src/interfaces/libpq/po/zh_TW.mo
? src/pl/plpgsql/src/plpgsql.def
? src/port/pg_config_paths.h
Index: doc/src/sgml/backup.sgml
===================================================================
RCS file: /projects/cvsroot/pgsql/doc/src/sgml/backup.sgml,v
retrieving revision 2.65
diff -u -r2.65 backup.sgml
--- doc/src/sgml/backup.sgml	19 Apr 2005 01:39:50 -0000	2.65
+++ doc/src/sgml/backup.sgml	20 Jun 2005 10:28:21 -0000
@@ -177,11 +177,11 @@
 </synopsis>
     The resulting dump can be restored with <application>psql</>:
 <synopsis>
-psql -f <replaceable class="parameter">infile</replaceable> template1
+psql -f <replaceable class="parameter">infile</replaceable> postgres
 </synopsis>
     (Actually, you can specify any existing database name to start from,
-    but if you are reloading in an empty cluster then <literal>template1</>
-    is the only available choice.)  It is always necessary to have
+    but if you are reloading in an empty cluster then <literal>postgres</>
+    should generally be used.)  It is always necessary to have
     database superuser access when restoring a <application>pg_dumpall</>
     dump, as that is required to restore the user and group information.
    </para>
@@ -1223,7 +1223,7 @@
    in parallel, on different ports. Then you can use something like
 
 <programlisting>
-pg_dumpall -p 5432 | psql -d template1 -p 6543
+pg_dumpall -p 5432 | psql -d postgres -p 6543
 </programlisting>
 
    to transfer your data.  Or use an intermediate file if you want.
@@ -1256,7 +1256,7 @@
 gmake install
 initdb -D /usr/local/pgsql/data
 postmaster -D /usr/local/pgsql/data
-psql -f backup template1
+psql -f backup postgres
 </programlisting>
 
    See <xref linkend="runtime"> about ways to start and stop the
Index: doc/src/sgml/charset.sgml
===================================================================
RCS file: /projects/cvsroot/pgsql/doc/src/sgml/charset.sgml,v
retrieving revision 2.72
diff -u -r2.72 charset.sgml
--- doc/src/sgml/charset.sgml	16 Apr 2005 16:50:01 -0000	2.72
+++ doc/src/sgml/charset.sgml	20 Jun 2005 10:29:32 -0000
@@ -647,6 +647,7 @@
  euc_kr        | t-ishii | EUC_KR
  euc_tw        | t-ishii | EUC_TW
  mule_internal | t-ishii | MULE_INTERNAL
+ postgres      | t-ishii | EUC_JP
  regression    | t-ishii | SQL_ASCII
  template1     | t-ishii | EUC_JP
  test          | t-ishii | EUC_JP
Index: doc/src/sgml/client-auth.sgml
===================================================================
RCS file: /projects/cvsroot/pgsql/doc/src/sgml/client-auth.sgml,v
retrieving revision 1.80
diff -u -r1.80 client-auth.sgml
--- doc/src/sgml/client-auth.sgml	4 Jun 2005 20:42:41 -0000	1.80
+++ doc/src/sgml/client-auth.sgml	20 Jun 2005 10:30:55 -0000
@@ -452,17 +452,17 @@
 host    all         all         127.0.0.1     255.255.255.255     trust     
 
 # Allow any user from any host with IP address 192.168.93.x to connect
-# to database "template1" as the same user name that ident reports for
+# to database "postgres" as the same user name that ident reports for
 # the connection (typically the Unix user name).
 # 
 # TYPE  DATABASE    USER        CIDR-ADDRESS          METHOD
-host    template1   all         192.168.93.0/24       ident sameuser
+host    postgres   all         192.168.93.0/24       ident sameuser
 
 # Allow a user from host 192.168.12.10 to connect to database
-# "template1" if the user's password is correctly supplied.
+# "postgres" if the user's password is correctly supplied.
 # 
 # TYPE  DATABASE    USER        CIDR-ADDRESS          METHOD
-host    template1   all         192.168.12.10/32      md5
+host    postgres    all         192.168.12.10/32      md5
 
 # In the absence of preceding "host" lines, these two lines will
 # reject all connection from 192.168.54.1 (since that entry will be
Index: doc/src/sgml/installation.sgml
===================================================================
RCS file: /projects/cvsroot/pgsql/doc/src/sgml/installation.sgml,v
retrieving revision 1.235
diff -u -r1.235 installation.sgml
--- doc/src/sgml/installation.sgml	12 Jun 2005 15:51:50 -0000	1.235
+++ doc/src/sgml/installation.sgml	20 Jun 2005 10:31:39 -0000
@@ -468,7 +468,7 @@
 </programlisting>
    Finally, restore your data with
 <screen>
-<userinput>/usr/local/pgsql/bin/psql -d template1 -f <replaceable>outputfile</></userinput>
+<userinput>/usr/local/pgsql/bin/psql -d postgres -f <replaceable>outputfile</></userinput>
 </screen>
    using the <emphasis>new</> <application>psql</>.
   </para>
Index: doc/src/sgml/libpq.sgml
===================================================================
RCS file: /projects/cvsroot/pgsql/doc/src/sgml/libpq.sgml,v
retrieving revision 1.185
diff -u -r1.185 libpq.sgml
--- doc/src/sgml/libpq.sgml	12 Jun 2005 00:00:20 -0000	1.185
+++ doc/src/sgml/libpq.sgml	20 Jun 2005 10:32:50 -0000
@@ -4230,14 +4230,14 @@
 
         /*
          * If the user supplies a parameter on the command line, use it as
-         * the conninfo string; otherwise default to setting dbname=template1
+         * the conninfo string; otherwise default to setting dbname=postgres
          * and using environment variables or defaults for all other connection
          * parameters.
          */
         if (argc &gt; 1)
                 conninfo = argv[1];
         else
-                conninfo = "dbname = template1";
+                conninfo = "dbname = postgres";
 
         /* Make a connection to the database */
         conn = PQconnectdb(conninfo);
@@ -4376,14 +4376,14 @@
 
         /*
          * If the user supplies a parameter on the command line, use it as
-         * the conninfo string; otherwise default to setting dbname=template1
+         * the conninfo string; otherwise default to setting dbname=postgres
          * and using environment variables or defaults for all other connection
          * parameters.
          */
         if (argc &gt; 1)
                 conninfo = argv[1];
         else
-                conninfo = "dbname = template1";
+                conninfo = "dbname = postgres";
 
         /* Make a connection to the database */
         conn = PQconnectdb(conninfo);
@@ -4518,14 +4518,14 @@
 
         /*
          * If the user supplies a parameter on the command line, use it as
-         * the conninfo string; otherwise default to setting dbname=template1
+         * the conninfo string; otherwise default to setting dbname=postgres
          * and using environment variables or defaults for all other connection
          * parameters.
          */
         if (argc &gt; 1)
                 conninfo = argv[1];
         else
-                conninfo = "dbname = template1";
+                conninfo = "dbname = postgres";
 
         /* Make a connection to the database */
         conn = PQconnectdb(conninfo);
Index: doc/src/sgml/manage-ag.sgml
===================================================================
RCS file: /projects/cvsroot/pgsql/doc/src/sgml/manage-ag.sgml,v
retrieving revision 2.41
diff -u -r2.41 manage-ag.sgml
--- doc/src/sgml/manage-ag.sgml	13 Jun 2005 02:40:04 -0000	2.41
+++ doc/src/sgml/manage-ag.sgml	20 Jun 2005 11:41:24 -0000
@@ -113,14 +113,14 @@
    <command>initdb</> command when the data storage area is
    initialized. (See <xref linkend="creating-cluster">.)  This
    database is called
-   <literal>template1</>.<indexterm><primary>template1</></> So to
+   <literal>postgres</>.<indexterm><primary>template1</></> So to
    create the first <quote>real</> database you can connect to
-   <literal>template1</>.
+   <literal>postgres</>.
   </para>
 
   <para>
-   The name <literal>template1</literal> is no accident: when a new
-   database is created, the template database is essentially cloned.
+   A second database, <literal>template1</literal> is also created: 
+   when a new database is created, the template database is essentially cloned.
    This means that any changes you make in <literal>template1</> are
    propagated to all subsequently created databases. This implies that
    you should not use the template database for real work, but when
@@ -273,7 +273,15 @@
     For example, one could drop <literal>template1</> and recreate it from
     <literal>template0</> without any ill effects.  This course of action
     might be advisable if one has carelessly added a bunch of junk in
-    <literal>template1</>.
+    <literal>template1</>. 
+   </para>
+   
+   <para>
+    The <literal>postgres</> database is provided as a default database for 
+    users and third party applications to use. It is simply a copy of template1
+    and may be dropped (and recreated) if required. Note that dropping
+    <literal>postgres</> may prevent some third party applications working correctly
+    without configuration changes.
    </para>
   </note>
  </sect1>
Index: doc/src/sgml/ref/createlang.sgml
===================================================================
RCS file: /projects/cvsroot/pgsql/doc/src/sgml/ref/createlang.sgml,v
retrieving revision 1.34
diff -u -r1.34 createlang.sgml
--- doc/src/sgml/ref/createlang.sgml	29 May 2005 03:32:18 -0000	1.34
+++ doc/src/sgml/ref/createlang.sgml	20 Jun 2005 11:45:32 -0000
@@ -219,9 +219,9 @@
 
    <para>
     To install the language <literal>pltcl</literal> into the database
-    <literal>template1</literal>:
+    <literal>postgres</literal>:
 <screen>
-<prompt>$ </prompt><userinput>createlang pltcl template1</userinput>
+<prompt>$ </prompt><userinput>createlang pltcl postgres</userinput>
 </screen>
    </para>
  </refsect1>
Index: doc/src/sgml/ref/drop_database.sgml
===================================================================
RCS file: /projects/cvsroot/pgsql/doc/src/sgml/ref/drop_database.sgml,v
retrieving revision 1.19
diff -u -r1.19 drop_database.sgml
--- doc/src/sgml/ref/drop_database.sgml	29 Nov 2003 19:51:38 -0000	1.19
+++ doc/src/sgml/ref/drop_database.sgml	20 Jun 2005 11:47:31 -0000
@@ -32,7 +32,7 @@
    catalog entries for the database and deletes the directory
    containing the data.  It can only be executed by the database owner.
    Also, it cannot be executed while you or anyone else are connected
-   to the target database.  (Connect to <literal>template1</literal> or any
+   to the target database.  (Connect to <literal>postgres</literal> or any
    other database to issue this command.) 
   </para>
 
Index: doc/src/sgml/ref/initdb.sgml
===================================================================
RCS file: /projects/cvsroot/pgsql/doc/src/sgml/ref/initdb.sgml,v
retrieving revision 1.34
diff -u -r1.34 initdb.sgml
--- doc/src/sgml/ref/initdb.sgml	22 Feb 2005 02:54:19 -0000	1.34
+++ doc/src/sgml/ref/initdb.sgml	20 Jun 2005 11:50:13 -0000
@@ -47,9 +47,11 @@
    which the database data will live, generating the shared catalog
    tables (tables that belong to the whole cluster rather than to any
    particular database), and creating the <literal>template1</literal>
-   database. When you later create a new database, everything in the
-   <literal>template1</literal> database is copied. It contains catalog
-   tables containing things like built-in data types.
+   and <literal>postgres</literal> databases. When you later create a 
+   new database, everything in the <literal>template1</literal> database is 
+   copied. It contains catalog tables containing things like built-in data 
+   types. The <literal>postgres</literal> database is a default database
+   for use by users and third party applications.
   </para>
 
   <para>
Index: doc/src/sgml/ref/pg_dumpall.sgml
===================================================================
RCS file: /projects/cvsroot/pgsql/doc/src/sgml/ref/pg_dumpall.sgml,v
retrieving revision 1.49
diff -u -r1.49 pg_dumpall.sgml
--- doc/src/sgml/ref/pg_dumpall.sgml	29 May 2005 03:32:18 -0000	1.49
+++ doc/src/sgml/ref/pg_dumpall.sgml	20 Jun 2005 11:51:47 -0000
@@ -401,7 +401,7 @@
   <para>
    To reload this database use, for example:
 <screen>
-<prompt>$</prompt> <userinput>psql -f db.out template1</userinput>
+<prompt>$</prompt> <userinput>psql -f db.out postgres</userinput>
 </screen>
    (It is not important to which database you connect here since the
    script file created by <application>pg_dumpall</application> will
Index: src/bin/initdb/initdb.c
===================================================================
RCS file: /projects/cvsroot/pgsql/src/bin/initdb/initdb.c,v
retrieving revision 1.84
diff -u -r1.84 initdb.c
--- src/bin/initdb/initdb.c	17 Jun 2005 22:32:47 -0000	1.84
+++ src/bin/initdb/initdb.c	20 Jun 2005 08:02:46 -0000
@@ -177,6 +177,7 @@
 static void set_info_version(void);
 static void setup_schema(void);
 static void vacuum_db(void);
+static void make_postgres(void);
 static void make_template0(void);
 static void trapsig(int signum);
 static void check_ok(void);
@@ -1828,6 +1829,37 @@
 }
 
 /*
+ * copy template1 to postgres
+ */
+static void
+make_postgres(void)
+{
+	PG_CMD_DECL;
+	char	  **line;
+	static char *default_setup[] = {
+		"CREATE DATABASE \"default\";\n",
+		NULL
+	};
+
+	fputs(_("copying template1 to postgres ... "), stdout);
+	fflush(stdout);
+
+	snprintf(cmd, sizeof(cmd),
+			 "\"%s\" %s template1 >%s",
+			 backend_exec, backend_options,
+			 DEVNULL);
+
+	PG_CMD_OPEN;
+
+	for (line = default_setup; *line; line++)
+		PG_CMD_PUTS(*line);
+
+	PG_CMD_CLOSE;
+
+	check_ok();
+}
+
+/*
  * copy template1 to template0
  */
 static void
@@ -2607,6 +2639,8 @@
 
 	vacuum_db();
 
+	make_postgres();
+    
 	make_template0();
 
 	if (authwarning != NULL)
Index: src/interfaces/ecpg/test/testdynalloc.pgc
===================================================================
RCS file: /projects/cvsroot/pgsql/src/interfaces/ecpg/test/testdynalloc.pgc,v
retrieving revision 1.1
diff -u -r1.1 testdynalloc.pgc
--- src/interfaces/ecpg/test/testdynalloc.pgc	16 Nov 2001 08:36:37 -0000	1.1
+++ src/interfaces/ecpg/test/testdynalloc.pgc	20 Jun 2005 09:23:55 -0000
@@ -13,7 +13,7 @@
    if (getenv("SQLOPT")) ECPGdebug(1,stderr);
 
    exec sql whenever sqlerror do sqlprint();
-   exec sql connect to template1;
+   exec sql connect to postgres;
    
    exec sql allocate descriptor mydesc;
    exec sql select tablename into descriptor mydesc from pg_tables;
Index: src/interfaces/libpq/pg_service.conf.sample
===================================================================
RCS file: /projects/cvsroot/pgsql/src/interfaces/libpq/pg_service.conf.sample,v
retrieving revision 1.2
diff -u -r1.2 pg_service.conf.sample
--- src/interfaces/libpq/pg_service.conf.sample	19 Dec 2003 21:50:54 -0000	1.2
+++ src/interfaces/libpq/pg_service.conf.sample	20 Jun 2005 09:24:52 -0000
@@ -4,13 +4,13 @@
 # A service is a set of named connection parameters.  You may specify
 # multiple services in this file.  Each starts with a service name in  
 # brackets.  Subsequent lines have connection configuration parameters of
-# the pattern  "param=value".  A sample configuration for template1 is 
+# the pattern  "param=value".  A sample configuration for postgres is 
 # included in this file.  Lines beginning with '#' are comments.
 #
 # Copy this to your sysconf directory (typically /usr/local/pgsql/etc) and
 # rename it pg_service.conf.
 #
 #
-#[template1]
-#dbname=template1
+#[postgres]
+#dbname=postgres
 #user=postgres
Index: src/test/examples/testlibpq.c
===================================================================
RCS file: /projects/cvsroot/pgsql/src/test/examples/testlibpq.c,v
retrieving revision 1.14
diff -u -r1.14 testlibpq.c
--- src/test/examples/testlibpq.c	1 Oct 2004 17:34:19 -0000	1.14
+++ src/test/examples/testlibpq.c	20 Jun 2005 09:26:39 -0000
@@ -26,14 +26,14 @@
 
 	/*
 	 * If the user supplies a parameter on the command line, use it as the
 	 * conninfo string; otherwise default to setting dbname=template1 and
 	 * using environment variables or defaults for all other connection
 	 * parameters.
 	 */
 	if (argc > 1)
 		conninfo = argv[1];
 	else
-		conninfo = "dbname = template1";
+		conninfo = "dbname = postgres";
 
 	/* Make a connection to the database */
 	conn = PQconnectdb(conninfo);
@@ -26,14 +26,14 @@
 	/*
 	 * If the user supplies a parameter on the command line, use it as the
-	 * conninfo string; otherwise default to setting dbname=template1 and
+	 * conninfo string; otherwise default to setting dbname=postgres and
 	 * using environment variables or defaults for all other connection
 	 * parameters.
Index: src/test/examples/testlibpq2.c
===================================================================
RCS file: /projects/cvsroot/pgsql/src/test/examples/testlibpq2.c,v
retrieving revision 1.11
diff -u -r1.11 testlibpq2.c
--- src/test/examples/testlibpq2.c	1 Oct 2004 17:34:19 -0000	1.11
+++ src/test/examples/testlibpq2.c	20 Jun 2005 09:27:07 -0000
@@ -46,14 +46,14 @@
 
 	/*
 	 * If the user supplies a parameter on the command line, use it as the
 	 * conninfo string; otherwise default to setting dbname=template1 and
 	 * using environment variables or defaults for all other connection
 	 * parameters.
 	 */
 	if (argc > 1)
 		conninfo = argv[1];
 	else
-		conninfo = "dbname = template1";
+		conninfo = "dbname = postgres";
 
 	/* Make a connection to the database */
 	conn = PQconnectdb(conninfo);
@@ -46,14 +46,14 @@
 	/*
 	 * If the user supplies a parameter on the command line, use it as the
-	 * conninfo string; otherwise default to setting dbname=template1 and
+	 * conninfo string; otherwise default to setting dbname=postgres and
 	 * using environment variables or defaults for all other connection
 	 * parameters.
Index: src/test/examples/testlibpq3.c
===================================================================
RCS file: /projects/cvsroot/pgsql/src/test/examples/testlibpq3.c,v
retrieving revision 1.10
diff -u -r1.10 testlibpq3.c
--- src/test/examples/testlibpq3.c	1 Oct 2004 17:34:19 -0000	1.10
+++ src/test/examples/testlibpq3.c	20 Jun 2005 09:27:31 -0000
@@ -51,14 +51,14 @@
 
 	/*
 	 * If the user supplies a parameter on the command line, use it as the
 	 * conninfo string; otherwise default to setting dbname=template1 and
 	 * using environment variables or defaults for all other connection
 	 * parameters.
 	 */
 	if (argc > 1)
 		conninfo = argv[1];
 	else
-		conninfo = "dbname = template1";
+		conninfo = "dbname = postgres";
 
 	/* Make a connection to the database */
 	conn = PQconnectdb(conninfo);
@@ -51,14 +51,14 @@
 	/*
 	 * If the user supplies a parameter on the command line, use it as the
-	 * conninfo string; otherwise default to setting dbname=template1 and
+	 * conninfo string; otherwise default to setting dbname=postgres and
 	 * using environment variables or defaults for all other connection
 	 * parameters.
